==> openjph-doc-0.24.2-1-any.pkg.tar.zst: usr/share/doc/openjph/search/defines_4.js <==
var searchData=
[
  ['ojph_5farch_5funknown_0',['OJPH_ARCH_UNKNOWN',['../ojph__arch_8h.html#a20f3aee839a664de54664b94675da0a0',1,'ojph_arch.h']]],
  ['ojph_5fdisable_5fsimd_1',['OJPH_DISABLE_SIMD',['../ojph__arch_8h.html#aaf2c7339c38f258a88da0d39c92e7848',1,'ojph_arch.h']]],
  ['ojph_5fdiv_5fceil_2',['ojph_div_ceil',['../ojph__defs_8h.html#a43333d02537e52329d7ea8e405420c67',1,'ojph_defs.h']]],
  ['ojph_5ferror_3',['OJPH_ERROR',['../ojph__message_8h.html#ae4546abbd8d73f3466a11084e562f099',1,'ojph_message.h']]],
  ['ojph_5fewouldblock_4',['OJPH_EWOULDBLOCK',['../ojph__sockets_8h.html#a8f17f09b0e42fd3149d364b901b7151d',1,'ojph_sockets.h']]],
  ['ojph_5fexport_5',['OJPH_EXPORT',['../ojph__arch_8h.html#a4055a02605d6ecfa700885833628647d',1,'ojph_arch.h']]],
  ['ojph_5finfo_6',['OJPH_INFO',['../ojph__message_8h.html#a83fc5ef7eace1ea8edd8bc89be67d407',1,'ojph_message.h']]],
  ['ojph_5fint_5fstringify_7',['OJPH_INT_STRINGIFY',['../ojph__defs_8h.html#a34dff1a2ee4de923e7455ecd1cbe1748',1,'ojph_defs.h']]],
  ['ojph_5fint_5fto_5fstring_8',['OJPH_INT_TO_STRING',['../ojph__defs_8h.html#a2c9176d8d2697bf0e930d654623447e5',1,'ojph_defs.h']]],
  ['ojph_5finvalid_5fsocket_9',['OJPH_INVALID_SOCKET',['../ojph__sockets_8h.html#a6f0207515a9bce1df6006e605ec8313e',1,'ojph_sockets.h']]],
  ['ojph_5fmax_10',['ojph_max',['../ojph__defs_8h.html#a0480926f2f10d84c1409ab9e7ac1fb1f',1,'ojph_defs.h']]],
  ['ojph_5fmin_11',['ojph_min',['../ojph__defs_8h.html#a5b92cd2d30b869b1026ab6baeeb31d16',1,'ojph_defs.h']]],
  ['ojph_5frepeat16_12',['OJPH_REPEAT16',['../ojph__block__decoder__wasm_8cpp.html#a92f62c9a36f5856dc8e1477410874154',1,'ojph_block_decoder_wasm.cpp']]],
  ['ojph_5frepeat2_13',['OJPH_REPEAT2',['../ojph__block__decoder__wasm_8cpp.html#a0cf67078bbe62fb5c8a6646084a05a95',1,'ojph_block_decoder_wasm.cpp']]],
  ['ojph_5frepeat4_14',['OJPH_REPEAT4',['../ojph__block__decoder__wasm_8cpp.html#a367a05242cc1da2d8811645843f2b8c3',1,'ojph_block_decoder_wasm.cpp']]],
  ['ojph_5frepeat8_15',['OJPH_REPEAT8',['../ojph__block__decoder__wasm_8cpp.html#ad23ef8612392bd58a1bf16da297686ca',1,'ojph_block_decoder_wasm.cpp']]],
  ['ojph_5funused_16',['ojph_unused',['../ojph__defs_8h.html#adf52fe9ad95bc92b1e16628516698c60',1,'ojph_defs.h']]],
  ['ojph_5fwarn_17',['OJPH_WARN',['../ojph__message_8h.html#afa8368270d0003264e2f80353a7c4563',1,'ojph_message.h']]],
  ['openjph_5fversion_5fmajor_18',['OPENJPH_VERSION_MAJOR',['../ojph__version_8h.html#aa326c5258b597fb73c8027f3c66c7bb3',1,'ojph_version.h']]],
  ['openjph_5fversion_5fminor_19',['OPENJPH_VERSION_MINOR',['../ojph__version_8h.html#aa8a00aeb9a2cf1bb203958fb0cfc0c18',1,'ojph_version.h']]],
  ['openjph_5fversion_5fpatch_20',['OPENJPH_VERSION_PATCH',['../ojph__version_8h.html#a2115c07ef1f29ae16add37e4d3a900c4',1,'ojph_version.h']]],
  ['out_5ffile_5fdir_21',['OUT_FILE_DIR',['../test__executables_8cpp.html#a340e101656b0ec8b031310125759554c',1,'test_executables.cpp']]]
];

==> openjph-doc-0.25.2-1-any.pkg.tar.zst: usr/share/doc/openjph/search/defines_4.js <==
var searchData=
[
  ['ojph_5farch_5funknown_0',['OJPH_ARCH_UNKNOWN',['../ojph__arch_8h.html#a20f3aee839a664de54664b94675da0a0',1,'ojph_arch.h']]],
  ['ojph_5fdisable_5fsimd_1',['OJPH_DISABLE_SIMD',['../ojph__arch_8h.html#aaf2c7339c38f258a88da0d39c92e7848',1,'ojph_arch.h']]],
  ['ojph_5fdiv_5fceil_2',['ojph_div_ceil',['../ojph__defs_8h.html#a43333d02537e52329d7ea8e405420c67',1,'ojph_defs.h']]],
  ['ojph_5ferror_3',['OJPH_ERROR',['../ojph__message_8h.html#ae4546abbd8d73f3466a11084e562f099',1,'ojph_message.h']]],
  ['ojph_5fewouldblock_4',['OJPH_EWOULDBLOCK',['../ojph__sockets_8h.html#a8f17f09b0e42fd3149d364b901b7151d',1,'ojph_sockets.h']]],
  ['ojph_5fexport_5',['OJPH_EXPORT',['../ojph__arch_8h.html#a4055a02605d6ecfa700885833628647d',1,'OJPH_EXPORT:&#160;ojph_arch.h'],['../ojph__mem_8c.html#a4055a02605d6ecfa700885833628647d',1,'OJPH_EXPORT:&#160;ojph_mem.c']]],
  ['ojph_5finfo_6',['OJPH_INFO',['../ojph__message_8h.html#a83fc5ef7eace1ea8edd8bc89be67d407',1,'ojph_message.h']]],
  ['ojph_5fint_5fstringify_7',['OJPH_INT_STRINGIFY',['../ojph__defs_8h.html#a34dff1a2ee4de923e7455ecd1cbe1748',1,'ojph_defs.h']]],
  ['ojph_5fint_5fto_5fstring_8',['OJPH_INT_TO_STRING',['../ojph__defs_8h.html#a2c9176d8d2697bf0e930d654623447e5',1,'ojph_defs.h']]],
  ['ojph_5finvalid_5fsocket_9',['OJPH_INVALID_SOCKET',['../ojph__sockets_8h.html#a6f0207515a9bce1df6006e605ec8313e',1,'ojph_sockets.h']]],
  ['ojph_5fmax_10',['ojph_max',['../ojph__defs_8h.html#a0480926f2f10d84c1409ab9e7ac1fb1f',1,'ojph_defs.h']]],
  ['ojph_5fmin_11',['ojph_min',['../ojph__defs_8h.html#a5b92cd2d30b869b1026ab6baeeb31d16',1,'ojph_defs.h']]],
  ['ojph_5frepeat16_12',['OJPH_REPEAT16',['../ojph__block__decoder__wasm_8cpp.html#a92f62c9a36f5856dc8e1477410874154',1,'ojph_block_decoder_wasm.cpp']]],
  ['ojph_5frepeat2_13',['OJPH_REPEAT2',['../ojph__block__decoder__wasm_8cpp.html#a0cf67078bbe62fb5c8a6646084a05a95',1,'ojph_block_decoder_wasm.cpp']]],
  ['ojph_5frepeat4_14',['OJPH_REPEAT4',['../ojph__block__decoder__wasm_8cpp.html#a367a05242cc1da2d8811645843f2b8c3',1,'ojph_block_decoder_wasm.cpp']]],
  ['ojph_5frepeat8_15',['OJPH_REPEAT8',['../ojph__block__decoder__wasm_8cpp.html#ad23ef8612392bd58a1bf16da297686ca',1,'ojph_block_decoder_wasm.cpp']]],
  ['ojph_5funused_16',['ojph_unused',['../ojph__defs_8h.html#adf52fe9ad95bc92b1e16628516698c60',1,'ojph_defs.h']]],
  ['ojph_5fwarn_17',['OJPH_WARN',['../ojph__message_8h.html#afa8368270d0003264e2f80353a7c4563',1,'ojph_message.h']]],
  ['openjph_5fversion_5fmajor_18',['OPENJPH_VERSION_MAJOR',['../ojph__version_8h.html#aa326c5258b597fb73c8027f3c66c7bb3',1,'ojph_version.h']]],
  ['openjph_5fversion_5fminor_19',['OPENJPH_VERSION_MINOR',['../ojph__version_8h.html#aa8a00aeb9a2cf1bb203958fb0cfc0c18',1,'ojph_version.h']]],
  ['openjph_5fversion_5fpatch_20',['OPENJPH_VERSION_PATCH',['../ojph__version_8h.html#a2115c07ef1f29ae16add37e4d3a900c4',1,'ojph_version.h']]],
  ['out_5ffile_5fdir_21',['OUT_FILE_DIR',['../test__executables_8cpp.html#a340e101656b0ec8b031310125759554c',1,'test_executables.cpp']]]
];
